/**
 * @file FmBuzzer.c
 * @brief Scratch用Buzzerドライバ
 */

#include <board.h>
#include <Std_Types.h>
#include "FmBuzzer.h"


static uint32_t FmBuzzer_Timer = 0;    /**< ブザータイマ Resolution 10[ms] */


/**
 * @brief Init
 */
void FmBuzzer_Init(void)
{
    FmBuzzer_Timer = 0;
}


/**
 * @brief 10ms定期処理
 */
void FmBuzzer_10msTask(void)
{
    /* ブザータイマ動作中 */
    if (FmBuzzer_Timer > 0)
    {
        /* ブザータイマ減算 */
        FmBuzzer_Timer--;
        
        /* ブザータイマが0になった */
        if (FmBuzzer_Timer == 0)
        {
            /* ブザーを止める */
            analogWrite(PIN_BUZZER, 0);
        }
    }
}


/**
 * @brief Set Freq
 * @param arg dummy
 * @param value 0=stop
 */
void FmBuzzer_SetFreq(uint32_t arg, int value)
{
    analogWrite(PIN_BUZZER, value);
}


/**
 * @brief Set Timer
 * @param arg dummy
 * @param value time[ms]
 */
void FmBuzzer_SetTimer(uint32_t arg, int value)
{
    FmBuzzer_Timer = value / 10;
}
