/**
 * @file FmLineTrace.c
 * @brief Scratch用LineTraceドライバ
 */

#include <board.h>


#define FmLineTrace_STOP        (0x00)
#define FmLineTrace_RUN         (0x01)
static int FmLineTrace_State = FmLineTrace_STOP;


#define LineTrace_Spd_Def       (45)
#define LineTrace_Spd_Dec       (0)
#define LineTrace_Black         (2300)

static int FmLineTrace_Thresh;
static int FmLineTrace_Speed;
static int FmLineTrace_Value1;

/**
 * @brief 初期化
 */
void FmLineTrace_Init(void)
{
    FmLineTrace_State = FmLineTrace_STOP;
    FmLineTrace_Thresh = LineTrace_Black;
    FmLineTrace_Speed = LineTrace_Spd_Def;
    FmLineTrace_Value1 = 0;
}


/**
 * @brief 10ms定期処理
 */
void FmLineTrace_10msTask(void)
{
    int motorL;
    int motorR;
    int lineL;
    int lineR;

    lineL = analogRead(PIN_LINE_L);
    lineR = analogRead(PIN_LINE_R);

    if (FmLineTrace_State == FmLineTrace_RUN) {
        /* 左右共に白なら */
        if ((lineL <= FmLineTrace_Thresh) && (lineR <= FmLineTrace_Thresh)) {
            /* 直進 */
            motorL = FmLineTrace_Speed;
            motorR = FmLineTrace_Speed;

        /* 左センサが黒を検知したら */
        } else if ((lineL > FmLineTrace_Thresh) && (lineR <= FmLineTrace_Thresh)) {
            /* 左モータの速度を下げる */
            motorL = LineTrace_Spd_Dec;
            motorR = FmLineTrace_Speed;

        /* 右センサが黒を検知したら */
        } else if ((lineL <= FmLineTrace_Thresh) && (lineR > FmLineTrace_Thresh)) {
            /* 右モータの速度を下げる */
            motorL = FmLineTrace_Speed;
            motorR = LineTrace_Spd_Dec;

        /* 両方黒なら */
        } else {
            motorL = FmLineTrace_Speed;
            motorR = FmLineTrace_Speed;
        }

        analogWrite(PIN_MOTOR_L, motorL);
        analogWrite(PIN_MOTOR_R, motorR);
    }
}


/**
 * @brief ライントレース有効化
 * @param isEnable 有効=1, 無効=0
 */
void FmLineTrace_SetEnable(int isEnable)
{
    /* 有効化 */
    if (isEnable)
    {
        FmLineTrace_State = FmLineTrace_RUN;
    }
    /* 無効化 */
    else
    {
        /* ブレーキをかける */
        analogWrite(PIN_MOTOR_L, -32768);
        analogWrite(PIN_MOTOR_R, -32768);
        
        FmLineTrace_State = FmLineTrace_STOP;
    }
}


/**
 * @brief Set Speed
 * @param arg dummy
 * @param value
 */
void FmLineTrace_SetSpeed(uint32_t arg, int value)
{
    FmLineTrace_Speed = value; 
    
}


/**
 * @brief Set Thresh
 * @param arg dummy
 * @param value
 */
void FmLineTrace_SetThresh(uint32_t arg, int value)
{
    FmLineTrace_Thresh = value;
}


/**
 * @brief Set Reserved Param
 * @param arg dummy
 * @param value
 */
void FmLineTrace_SetValue1(uint32_t arg, int value)
{
    FmLineTrace_Value1 = value;
}
