/**
 * @file FmMotor.c
 * @brief Scratch用Motorドライバ
 */

#include <board.h>
#include <Std_Types.h>
#include "FmMotor.h"


static uint32_t FmMotor_Timer_L = 0;    /**< モータタイマL Resolution 10[ms] */
static uint32_t FmMotor_Timer_R = 0;    /**< モータタイマR Resolution 10[ms] */


/**
 * @brief Init
 */
void FmMotor_Init(void)
{
    FmMotor_Timer_L = 0;
    FmMotor_Timer_R = 0;
}


/**
 * @brief 10ms定期処理
 */
void FmMotor_10msTask(void)
{
    /* Lモータタイマ動作中 */
    if (FmMotor_Timer_L > 0)
    {
        /* モータタイマ減算 */
        FmMotor_Timer_L--;
        
        /* タイマカウントが0になった */
        if (FmMotor_Timer_L == 0)
        {
            /* モータを止める */
            analogWrite(PIN_MOTOR_L, -32768);
        }
    }
    
    
    /* Rモータタイマ動作中 */
    if (FmMotor_Timer_R > 0)
    {
        /* モータタイマ減算 */
        FmMotor_Timer_R--;
        
        /* タイマカウントが0になった */
        if (FmMotor_Timer_R == 0)
        {
            /* モータを止める */
            analogWrite(PIN_MOTOR_R, -32768);
        }
    }
}


/**
 * @brief Set Motor
 * @param arg 0x00 l, 0x01 r
 * @param value 0-100
 */
void FmMotor_SetSpeed(uint32_t arg, int value)
{
    // 12bit signed -> 32bit signed
    if ((value & 0xFFFFF800) != 0)
    {
        value |= 0xFFFFF800;
    }

    /* Update Duty */
    if (arg == IDX_0)
    {
        analogWrite(PIN_MOTOR_L, value);
    }
    else if (arg == IDX_1)
    {
        analogWrite(PIN_MOTOR_R, value);
    }
    else
    {
        /* nothing to do */
    }
}


/**
 * @brief Set Timer
 * @param arg 0x00 l, 0x01 r
 * @param value time[ms]
 */
void FmMotor_SetTimer(uint32_t arg, int value)
{
    if (arg == IDX_0)
    {
        FmMotor_Timer_L = value / 10;
    }
    else if (arg == IDX_1)
    {
        FmMotor_Timer_R = value / 10;
    }
    else
    {
        /* nothing to do */
    }
}
