/**
 * @file FmTestApl.c
 * @brief Scratch用テスト動作ドライバ
 */

#include <board.h>
#include <Std_Types.h>

#include "Firmata.h"
#include "FmMotor.h"
#include "FmBuzzer.h"
#include "FmLCD.h"


static void FmTestApl_RunTest(void);


#define TEST_BUTTON_TIME (3000 / 10)
#define TEST_TIME       (2000 / 10)
#define TEST_LEDSOUNDTIME (200 / 10)


uint32_t FmTestApl_SwTimer;
uint32_t FmTestApl_StepTimer;
uint32_t FmTestApl_Step;
uint32_t FmTestApl_FLedCounter;
uint32_t FmTestApl_LedSoundTimer;
uint8_t FmTestApl_LedSoundState;

boolean FmTestApl_IsEnable;


/**
 * @brief Init
 */
void FmTestApl_Init(void)
{
    FmTestApl_IsEnable = FALSE;

    FmTestApl_SwTimer = 0;

    FmTestApl_FLedCounter = 0;
    FmTestApl_StepTimer = 0;
    FmTestApl_Step = 0;
    FmTestApl_LedSoundTimer = TEST_LEDSOUNDTIME - 1;
    FmTestApl_LedSoundState = 1;
}


/**
 * @brief 10ms定期処理
 */
void FmTestApl_Periodic(void)
{
    if (Firmata_IsConHistory() == FALSE)
    {
        if (digitalRead(PIN_BTN1) == TRUE && digitalRead(PIN_BTN2) == FALSE)
        {
            FmTestApl_SwTimer++;
            if (FmTestApl_SwTimer >= TEST_BUTTON_TIME)
            {
                FmTestApl_IsEnable = TRUE;
            }
        }
        else
        {
            FmTestApl_SwTimer = 0;
        }
        
        if (FmTestApl_IsEnable == TRUE)
        {
            FmTestApl_RunTest();
        }
    }
    else
    {
        FmTestApl_Init();
    }
}


/**
 * @brief RunTest
 */
static void FmTestApl_RunTest(void)
{
    if (FmTestApl_Step == 0)
    {
        /* Step1 Bzのみ */
        FmTestApl_StepTimer = 0;
        FmTestApl_Step = 1;

        FmBuzzer_SetFreq(0, 2000);
        FmBuzzer_SetTimer(0, 100);

    }
    else if (FmTestApl_Step == 1)
    {
        FmTestApl_StepTimer++;
        if (FmTestApl_StepTimer > TEST_TIME)
        {
            FmTestApl_StepTimer = 0;
            FmTestApl_Step = 2;

            /* Step2 前進 */
            FmLCD_SetMonitorEnable(1);

            FmBuzzer_SetFreq(0, 2000);
            FmBuzzer_SetTimer(0, 100);

            FmMotor_SetSpeed(0, 50);
            FmMotor_SetTimer(0, 3000);
            FmMotor_SetSpeed(1, 50);
            FmMotor_SetTimer(1, 3000);
        }
    }
    else if (FmTestApl_Step == 2)
    {
        FmTestApl_StepTimer++;
        if (FmTestApl_StepTimer > TEST_TIME)
        {
            FmTestApl_StepTimer = 0;
            FmTestApl_Step = 3;

            /* Step3 後退 */
            FmBuzzer_SetFreq(0, 2000);
            FmBuzzer_SetTimer(0, 100);

            FmMotor_SetSpeed(0, -50);
            FmMotor_SetTimer(0, 3000);
            FmMotor_SetSpeed(1, -50);
            FmMotor_SetTimer(1, 3000);

        }
    }
    else if (FmTestApl_Step == 3)
    {

        FmTestApl_StepTimer++;
        if (FmTestApl_StepTimer > TEST_TIME)
        {
            FmTestApl_StepTimer = 0;
            FmTestApl_Step = 4;

            /* Step4 右回転 */
            FmBuzzer_SetFreq(0, 2000);
            FmBuzzer_SetTimer(0, 100);

            FmMotor_SetSpeed(0, 50);
            FmMotor_SetTimer(0, 3000);
            FmMotor_SetSpeed(1, -50);
            FmMotor_SetTimer(1, 3000);
        }
    }
    else if (FmTestApl_Step == 4)
    {
        FmTestApl_StepTimer++;
        if (FmTestApl_StepTimer > TEST_TIME)
        {
            FmTestApl_StepTimer = 0;
            FmTestApl_Step = 5;

            /* Step5 停止 */
            FmBuzzer_SetFreq(0, 2000);
            FmBuzzer_SetTimer(0, 100);

            FmMotor_SetSpeed(0, 0);
            FmMotor_SetSpeed(1, 0);
        }
    }
    else
    {
    }

    /* LED / SoundTest */
    FmTestApl_LedSoundTimer++;
    if (FmTestApl_LedSoundTimer >= TEST_LEDSOUNDTIME)
    {
        FmTestApl_LedSoundTimer = 0;

        switch (FmTestApl_FLedCounter)
        {
        case 0:
            analogWrite(PIN_FLED_R, 100);
            analogWrite(PIN_FLED_G, 0);
            analogWrite(PIN_FLED_B, 0);
            break;
        case 1:
            analogWrite(PIN_FLED_R, 0);
            analogWrite(PIN_FLED_G, 100);
            analogWrite(PIN_FLED_B, 0);
            break;
        case 2:
            analogWrite(PIN_FLED_R, 0);
            analogWrite(PIN_FLED_G, 0);
            analogWrite(PIN_FLED_B, 100);
            break;
        default:
            break;
        }

        FmTestApl_FLedCounter = (FmTestApl_FLedCounter < 2) ? (FmTestApl_FLedCounter + 1) : 0;



        FmTestApl_LedSoundState =  (FmTestApl_LedSoundState >= 0x40 || FmTestApl_LedSoundState == 0x00) ? (0x01) : (FmTestApl_LedSoundState << 1);

        digitalWrite(PIN_LED1, ((FmTestApl_LedSoundState - 1) >> 0) & 0x01);
        digitalWrite(PIN_LED2, ((FmTestApl_LedSoundState - 1) >> 1) & 0x01);
        digitalWrite(PIN_LED3, ((FmTestApl_LedSoundState - 1) >> 2) & 0x01);
        digitalWrite(PIN_LED4, ((FmTestApl_LedSoundState - 1) >> 3) & 0x01);
        digitalWrite(PIN_LED5, ((FmTestApl_LedSoundState - 1) >> 4) & 0x01);
        digitalWrite(PIN_LED6, ((FmTestApl_LedSoundState - 1) >> 5) & 0x01);
    }
}
