/**
 * @file SchM_Cfg.c
 * @brief タスクの設定ファイル
 */
#include <Std_Types.h>
#include <stdio.h>

#include "SchM.h"


#include <BSW/IODrivers/Adc.h>
#include <BSW/IODrivers/I2c.h>
#include <BSW/IODrivers/Mtu3Drv.h>
#include <BSW/IODrivers/MotorDrv.h>
#include <BSW/IODrivers/Buzzer.h>
#include <BSW/IODrivers/Distance.h>
#include <BSW/IODrivers/FCLedDrv.h>
#include <BSW/IODrivers/Sci.h>
#include <BSW/IODrivers/LcdDrv.h>

#include <BSW/IODrivers/IODrv.h>
#include <APL/Firmata.h>


/**
 * @brief 初期化
 * 初期化処理を記述
 */
void SchM_Cfg_Init(void)
{
    setbuf(stdout, NULL);       /* No buffering */

    Adc_Init();
    Buzzer_Init();

    Mtu3Drv_Init();
    MotorDrv_Init();

    Distance_Init();
    
    Sci_Init(57600);
    I2c_Init(0);
    LcdDrv_Init();
    FCLedDrv_Init();
    
    Firmata_Init();
}


/**
 * @brief IDLEタスク
 * 他のタスクを実行していない時に実行する制御を定義
 */
void SchM_Cfg_Task_Idle(void)
{
}


/**
 * @brief 定期10msタスク
 * 10ms毎に実行する制御を定義
 */
void SchM_Cfg_Task_Periodic10ms(void)
{
    Distance_Periodic();
    MotorDrv_Periodic();
    
    IODrv_Periodic();

    Firmata_10msTask();
    
    LcdDrv_PeriodicTask();

}


/**
 * @brief 割込み1msタスク
 * 1ms毎に実行する制御を定義
 * 本関数は割込みで呼び出しされる
 */
void SchM_Cfg_Task_Int1ms(void)
{
    Adc_StartConversion();
    IODrv_1msInt();
}
